#
# spec file for package perl-Devel-CheckLib
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Devel-CheckLib
Name:           perl-Devel-CheckLib
Version:        1.160.0
Release:        1.1
# 1.16 -> normalize -> 1.160.0
%define cpan_version 1.16
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Check that a library is available
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MA/MATTN/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Capture::Tiny)
BuildRequires:  perl(Mock::Config) >= 0.20
BuildRequires:  perl(Test::More) >= 0.88
Provides:       perl(Devel::CheckLib) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
Devel::CheckLib is a perl module that checks whether a particular C library
and its headers are available.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc CHANGES README TODO VMS-notes

%changelog
* Tue May 20 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Thu May  5 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.16
  see /usr/share/doc/packages/perl-Devel-CheckLib/CHANGES
  1.16    2022-05-04      Stop all the tests that require a working compiler from
    skipping on AIX
  1.15    2022-05-04      Refactor, stop GCC optimising away test code
* Thu Nov 14 2019 <timueller+perl@suse.de>
- updated to 1.14
  see /usr/share/doc/packages/perl-Devel-CheckLib/CHANGES
  1.14    2019-11-12      Use Capture::Tiny instead of Capture::Output
* Mon Jun  4 2018 coolo@suse.com
- updated to 1.13
  see /usr/share/doc/packages/perl-Devel-CheckLib/CHANGES
  1.13    2018-06-23      Improve Makefile.PL
    update compatibility code from App-EUMM-Upgrade-1.0
* Fri Jun  1 2018 coolo@suse.com
- updated to 1.12
  see /usr/share/doc/packages/perl-Devel-CheckLib/CHANGES
  1.12    2018-05-23      Fix order of flags for gcc
    Fix problems with executable binaries
* Mon Oct 16 2017 coolo@suse.com
- updated to 1.11
  see /usr/share/doc/packages/perl-Devel-CheckLib/CHANGES
  1.11    2017-05-23      Prevent concatenation warnings when LD_RUN_PATH is
    undefined.
  1.10    2017-04-08      Use Mock::Config.
  1.09    2017-04-08      Remove link options from @ldflags.
* Sun Mar 19 2017 coolo@suse.com
- updated to 1.09
  see /usr/share/doc/packages/perl-Devel-CheckLib/CHANGES
  1.09    2017-03-18      Add $PATH for the libs on Windows.
  1.08    2017-03-18      Add $LD_RUN_PATH for the libs.
* Mon Apr 11 2016 coolo@suse.com
- updated to 1.07
  see /usr/share/doc/packages/perl-Devel-CheckLib/CHANGES
  1.07    2016-04-09      Add analyze_binary feature.
* Sun Feb 21 2016 coolo@suse.com
- updated to 1.06
  see /usr/share/doc/packages/perl-Devel-CheckLib/CHANGES
* Sun Sep 20 2015 coolo@suse.com
- updated to 1.05
  see /usr/share/doc/packages/perl-Devel-CheckLib/CHANGES
  1.05	2015-09-16	Fix handling $PERL_MM_OPT.
  1.04	2015-09-16	Handle $PERL_MM_OPT.
* Sat Feb  7 2015 coolo@suse.com
- updated to 1.03
  * Fix possible crash bug on windows.
    Remove .exe when it run on cygwin.
* Sat Mar 22 2014 coolo@suse.com
- regenerate with cpan2spec
* Fri Mar 21 2014 mlin@suse.com
- update to 1.01
  * Deprecate use-devel-checklib script.
  * Allow -R rpaths as libpaths used with solaris cc (see RT #81330)
  * Merge ldflags & perllibs.
  * Fixed test.
  * Pass linker options to MSVC.
  * Clean up object files. Also MSVC generates extra files, clean them up.
  * Better error message.
  * Add support for gcc that have version number in the command name.
    Fix about that the command path include space character.
* Sat Jan 22 2011 coolo@novell.com
- update to 0.92
  * Patch included, thanks to CHM and SISYPHUS (see RT #63742)
  * Fix deprecated parenthesis. use "(qw())".
  * Add include header files into dependencies files.
  (see RT #61297)
  * Add support for checking if a function exists
  in a library and it returns the right value
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Mon Aug 23 2010 pascal.bleser@opensuse.org
- initial package (0.6)
